@@ -5,22 +5,22 @@ use warnings;
 use bytes;
 require Exporter ;
 
-use IO::Compress::Base 2.212 ;
-use IO::Compress::Base::Common  2.212 qw(createSelfTiedObject);
-use IO::Compress::Adapter::Xz 2.212 ;
-use Compress::Raw::Lzma  2.212 ;
+use IO::Compress::Base 2.214 ;
+use IO::Compress::Base::Common  2.214 qw(createSelfTiedObject);
+use IO::Compress::Adapter::Xz 2.214 ;
+use Compress::Raw::Lzma  2.214 ;
 
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $XzError);
 
-$VERSION = '2.212';
+$VERSION = '2.214';
 $XzError = '';
 
 @ISA    = qw(IO::Compress::Base Exporter);
 @EXPORT_OK = qw( $XzError xz ) ;
 %EXPORT_TAGS = %IO::Compress::Base::EXPORT_TAGS ;
 
-push @{ $EXPORT_TAGS{constants} }, @Compress::Raw::Lzma::EXPORT;
+$EXPORT_TAGS{constants} = [ defined $EXPORT_TAGS{constants} ? @{ $EXPORT_TAGS{constants} } : (), @Compress::Raw::Lzma::EXPORT] ;
 $EXPORT_TAGS{all} = $EXPORT_TAGS{constants} ;
 
 push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
@@ -859,7 +859,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2024 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2025 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
