@@ -4,21 +4,21 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common 2.213 qw(:Status createSelfTiedObject);
+use IO::Compress::Base::Common 2.214 qw(:Status createSelfTiedObject);
 
-use IO::Uncompress::Base 2.213 ;
-use IO::Uncompress::Adapter::UnXz 2.213 ;
+use IO::Uncompress::Base 2.214 ;
+use IO::Uncompress::Adapter::UnXz 2.214 ;
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnXzError);
 
-$VERSION = '2.213';
+$VERSION = '2.214';
 $UnXzError = '';
 
 @ISA    = qw( IO::Uncompress::Base Exporter );
 @EXPORT_OK = qw( $UnXzError unxz ) ;
 #%EXPORT_TAGS = %IO::Uncompress::Base::EXPORT_TAGS ;
-push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
+$EXPORT_TAGS{all} = [ defined $EXPORT_TAGS{all} ? @{ $EXPORT_TAGS{all} } : (), @EXPORT_OK ] ;
 #Exporter::export_ok_tags('all');
 
 
@@ -921,7 +921,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2024 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2025 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
